import 'package:dio/dio.dart';
import 'package:flutter_tracker/dio/api.dart';
import 'package:flutter_tracker/model/base_model.dart';
import 'package:flutter_tracker/model/login_entity.dart';
import 'package:flutter_tracker/model/user_model.dart';

/// Description:
/// Time       : 2021年12月03日 Friday
/// Author     : liuyuqi.gov@msncn
class LoginDao {
  static Map<String, dynamic> params = <String, dynamic>{};

  /// login
  static Future<LoginEntity> login(String username, String password) async {
    params.addAll({"username": username, "password": password});
    try {
      Response response = await Dio().post(Api.loginUrl, data: params);
      return LoginEntity.fromJson(response.data);
    } catch (e) {
      return LoginEntity.fromJson({"success": false, "msg": "网络错误"});
    }
  }

  /// logout
  static Future<BaseModel> logout(String token) async {
    params.addAll({"token": token});
    try {
      Response response = await Dio().post(Api.logoutUrl, data: params);
      return BaseModel.fromJson(response.data);
    } catch (e) {
      return BaseModel.fromJson({"success": false, "msg": "网络错误"});
    }
  }

  static Future<BaseModel> register(String username, String password) async {
    params.addAll({"username": username, "password": password});
    try {
      Response response = await Dio().post(Api.registerUrl, data: params);
      if (response.data["success"] == true) {}
      return BaseModel.fromJson(response.data);
    } catch (e) {
      return BaseModel.fromJson({"success": false, "msg": "网络错误"});
    }
  }

  static Future<UserModel> getUserInfo(String token) async {
    params.addAll({"token": token});
    Response response = await Dio().post(Api.getUserInfoUrl, data: params);
    return UserModel.fromJson(response.data);
  }

  //通过设备id查找用户
  static Future<UserModel> getUserByDeviceId(String deviceid) async {
    params.addAll({"deviceid": deviceid});
    Response response = await Dio().post(Api.getUserByDeviceId, data: params);
    return UserModel.fromJson(response.data);
  }
}
